Spiker’s Documentation — Spiker documentation

# Spiker’s Documentation

Introduction

- Introduction to spike-in control

Installation

- 1. Prerequisites
- 2. Python Dependencies
- 3. Install Spiker
- 4. Uninstall
- 5. Upgrade Spiker

Usage information

- 1. Analysis workflow
- 2. Input and output
- 3. Command options

Walkthrough example

- 1. Prepare FASTQ files
- 2. Build bowtie2 index files
- 3. Map reads to the composite reference genome
- 4. Calculate scaling factors
- 5. Run Spiker

Bowtie2 Index Files

- 1. Bowtie2 index files
- 2. Index files for Human + Drosophila
- 3. Index files for Mouse + Drosophila

Test Dataset

- 1. Test dataset
- 2. H3K79me2 ChIP-seq data
- 3. WCE (whole cell extract) data
- 4. MD5sum

Release history

- 1. Release history
  - 1.1. Version 1.0.0

Liscense

- LICENSE